//
//  ViewController.swift
//  UIStackViewDemo
//
//  Created by mac on 16/6/4.
//  Copyright © 2016年 Gaol. All rights reserved.
//

import UIKit

/*Stack View会被当成Container View。所以它是一个不会被渲染的UIView子类。它不像其他UIView子类一样，会被渲染到屏幕上。这也意味着设置其backgroundColor属性或重载drawRect:方法都不会产生任何效果。*/

/*如果你想添加一个subview给Stack View管理，你应该调用addArrangedSubview:或insertArrangedSubview:atIndex: arrangedSubviews数组是subviews属性的子集。
 
 要移除Stack View管理的subview，需要调用removeArrangedSubview:和removeFromSuperview。移除arrangedSubview只是确保Stack View不再管理其约束，而非从视图层次结构中删除.*/

class ViewController: UIViewController {
    
    //上半部
    var verticalStack: UIStackView!
    var labeltitle: UILabel!
    var imgLogo: UIImageView!
    var btnAdd: UIButton!
    var btnRemove: UIButton!
    var horizontalsubview: UIStackView!
    
    //下半部
    var horizontal: UIStackView!
    
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        initSubViews()
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    
    //MARK： 加载控件
    func  initSubViews(){
        
        
        //上半部
        verticalStack = UIStackView(frame: CGRectMake(0,40,self.view.bounds.width,self.view.bounds.height - 200))
        verticalStack.axis = .Vertical
        verticalStack.alignment = .Center
        verticalStack.distribution = .EqualSpacing
        verticalStack.spacing = 30.0
        self.view.addSubview(verticalStack)
        
        labeltitle = UILabel()
        labeltitle.textAlignment = .Center
        labeltitle.text = "HelLo,海贼王，路飞酱"
        labeltitle.textColor = UIColor.blackColor()
        verticalStack.addArrangedSubview(labeltitle)
        
        imgLogo = UIImageView()
        imgLogo.image = UIImage(named: "logo.png")
        imgLogo.contentMode = .ScaleAspectFit
        verticalStack.addArrangedSubview(imgLogo)
        
        horizontalsubview = UIStackView()
        horizontalsubview.axis = .Horizontal
        horizontalsubview.alignment = .Leading
        horizontalsubview.distribution = .EqualSpacing
        horizontalsubview.spacing = 50
        verticalStack.addArrangedSubview(horizontalsubview)
        
        btnAdd = UIButton()
        btnAdd.setTitle("AddStars", forState: .Normal)
        btnAdd.setTitleColor(UIColor.orangeColor(), forState: .Normal)
        btnAdd.addTarget(self, action: #selector(addAction(_:)), forControlEvents: .TouchUpInside)
        horizontalsubview.addArrangedSubview(btnAdd)
        
        
        btnRemove = UIButton()
        btnRemove.setTitle("RemoveStar", forState: .Normal)
        btnRemove.setTitleColor(UIColor.redColor(), forState: .Normal)
        btnRemove.addTarget(self, action: #selector(removeAction(_:)), forControlEvents: .TouchUpInside)
        horizontalsubview.addArrangedSubview(btnRemove)
        
        //下半部
        
        horizontal = UIStackView(frame: CGRectMake(0,verticalStack.bounds.size.height + 80, self.view.bounds.width, 50))
        horizontal.axis = .Horizontal
        horizontal.alignment = .Center
        horizontal.distribution = .FillEqually
        self.view.addSubview(horizontal)
        
    }
    
    
    func addAction(sender:UIButton){
        
        let imgStar = UIImageView(image: UIImage(named: "star.png"))
        imgStar.contentMode = .ScaleAspectFit
        self.horizontal.addArrangedSubview(imgStar)
        UIView.animateWithDuration(0.25) {
            self.horizontal.layoutIfNeeded()
        }
    }
    
    func removeAction(sender:UIButton){
        
        let star  = self.horizontal.arrangedSubviews.last
        if let aStar = star {
            self.horizontal.removeArrangedSubview(aStar)
            aStar.removeFromSuperview()
            UIView.animateWithDuration(0.25, animations: {
                self.horizontal.layoutIfNeeded()
            })
        }
    }
    
    override func shouldAutorotate() -> Bool {
        
        return false
    }
    
    
}

